function test_suite = test_excludeSmallSampleSizes
initTestSuite;


function initData = setup 
% create input data: is run before each test cast again

% number of assets
nAss = 30;

% set anchor date: sample end at this data
currDate = 735466;

% get sample sizes
sampleSizes = [repmat(300, 1, 3) repmat(1500, 1, nAss-3)];

% init .Date and .Ticker fields: sample sizes are
% determined on .Date field only 
for ii=1:nAss
    % create dates for ii-th asset
    dateVector = currDate:-1:...
        (currDate - sampleSizes(ii) + 1);
    
    if (length(dateVector) ~= sampleSizes(ii))
        error('created date vector is of wrong size') 
    end
    
    % add structure object
    dataStructArr(ii) = struct('Date', dateVector, ...
                               'Ticker', num2str(ii)); 
end
initData = dataStructArr;

% function teardown(initData)
% delete 'initData';


function testThresholdDetermination1(initData)
exp_out = 0.9*100;
out = thresholdDetermination(100*ones(1,10));
assertEqual(exp_out, out)


function testThresholdDetermination2(iniData)
exp_out = 0.9*50;
out = thresholdDetermination([100*ones(1,10) 50*ones(1,100)]);
assertEqual(exp_out, out)


function testNoRemaining(initData)
% calculate function output
[remainingData, excluded] = ...
    excludeSmallSampleSizes(initData);
assertEqual(27, length(remainingData));


function testNoExcluded(initData)
% calculate function output
[remainingData, excluded] = ...
    excludeSmallSampleSizes(initData);
assertEqual(3, length(excluded.Assets));


function testExcludedSampleSizes(initData)
% calculate function output
[remainingData, excluded] = ...
    excludeSmallSampleSizes(initData);
assertEqual(300*ones(3,1), excluded(1).Sample_sizes(:));


function testRemainingSampleSizes(initData)
% calculate function output
[remainingData, excluded] = ...
    excludeSmallSampleSizes(initData);
assertEqual(1500, length(remainingData(1).Date))




